abacusai.annotation_document — AbacusAI documentation

# abacusai.annotation_document

## Classes

`AnnotationDocument` | Document to be annotated.

## Module Contents

class abacusai.annotation_document.AnnotationDocument(client, docId=None, featureGroupRowIdentifier=None, featureGroupRowIndex=None, totalRows=None, isAnnotationPresent=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Document to be annotated.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - docId (str) – The docstore Document ID of the document.

    - featureGroupRowIdentifier (str) – The key value of the feature group row the annotation is on. Usually the primary key value.

    - featureGroupRowIndex (int) – The index of the document row in the feature group.

    - totalRows (int) – The total number of rows in the feature group.

    - isAnnotationPresent (bool) – Whether the document already has an annotation. Returns None if feature group is not under annotations review mode.

  doc_id = None
  feature_group_row_identifier = None
  feature_group_row_index = None
  total_rows = None
  is_annotation_present = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict